"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = require("react");
function moveCaretToEndOfText(el) {
    const target = el.nodeType === Node.TEXT_NODE ? el : el.childNodes[0];
    if (target !== null && target.nodeValue !== null) {
        const sel = getSelection();
        if (sel !== null) {
            const range = document.createRange();
            range.setStart(target, target.nodeValue.length);
            range.collapse(true);
            sel.removeAllRanges();
            sel.addRange(range);
        }
    }
}
exports.moveCaretToEndOfText = moveCaretToEndOfText;
exports.MoveFocusKeyCodes = [38, 40, 37, 39];
const StartEditCodes = [13, 32];
const EscapeCode = 27;
function useFocusAndEditable(cellRef, isInFocus, events) {
    const [editMode, setEditMode] = react_1.useState(false);
    const stopEditHandler = react_1.useCallback((e) => {
        setEditMode(false);
        events.onEdit();
    }, []);
    const setEditModeHandler = react_1.useCallback((e) => setEditMode(true), []);
    const setEditModeOrFocus = react_1.useCallback((e) => {
        if (isInFocus) {
            setEditModeHandler(e);
            e.stopPropagation();
        }
        else {
            events.onFocus();
        }
    }, [isInFocus]);
    const moveFocus = react_1.useCallback((e) => {
        if (!editMode) {
            if (exports.MoveFocusKeyCodes.includes(e.keyCode)) {
                events.onMoveFocus(e.keyCode);
            }
            if (StartEditCodes.includes(e.keyCode)) {
                setEditModeHandler(e);
            }
            e.preventDefault();
        }
        else if (e.keyCode === EscapeCode) {
            stopEditHandler(e);
        }
    }, [editMode, cellRef.current]);
    react_1.useEffect(() => {
        if (cellRef.current) {
            cellRef.current.addEventListener('click', setEditModeOrFocus);
            cellRef.current.addEventListener("dblclick", setEditModeHandler);
            if (editMode) {
                moveCaretToEndOfText(cellRef.current);
            }
            if (isInFocus || editMode) {
                cellRef.current.focus();
                cellRef.current.addEventListener("keydown", moveFocus);
                cellRef.current.addEventListener("blur", stopEditHandler);
            }
        }
        return () => {
            if (cellRef.current) {
                cellRef.current.removeEventListener('click', setEditModeOrFocus);
                cellRef.current.removeEventListener("dblclick", setEditModeHandler);
                if (isInFocus) {
                    cellRef.current.removeEventListener("keydown", moveFocus);
                    cellRef.current.removeEventListener("blur", stopEditHandler);
                }
            }
        };
    }, [isInFocus, cellRef.current, editMode]);
    return editMode;
}
exports.useFocusAndEditable = useFocusAndEditable;
//# sourceMappingURL=editable.js.map